Websites using django-embed-video
=================================

- `Al.ta Cucina <https://altacucina.co>`_
- `Bici.news <https://bici.news>`_
- `Outdoor Passion <https://www.outdoorpassion.it>`_
- `Snow Passion <https://www.snowpassion.it>`_
- `Running Passion <https://www.runningpassion.it>`_

*Are you using django-embed-video? Send pull request!*



